@@ -27,13 +27,13 @@
 #include <QtCore/QPointer>
 
 #include <KgTheme>
+#include <QIcon>
 #include <KGameRenderer>
-#include <KStandardDirs>
 #include <KConfigSkeleton>
 #include <KNS3/DownloadDialog>
-#include <KSaveFile>
+#include <QFile>
 #include <QDir>
-#include <KComponentData>
+#include <QStandardPaths>
 
 #include "ui_arenaselector.h"
 #include "arenasettings.h"
@@ -101,7 +101,7 @@ void ArenaSelector::showEvent(QShowEvent*)
 ArenaSelector::Private::Private(ArenaSelector* parent, Options options) : q(parent), m_options(options), m_arena(NULL), m_graphicsScene(NULL), m_svgScaleFactor(1)
 {
     KgTheme* theme = new KgTheme(QByteArray());
-    theme->setGraphicsPath(KStandardDirs::locate("appdata", QString("themes/granatier.svgz")));
+    theme->setGraphicsPath(QStandardPaths::locate(QStandardPaths::DataLocation, QString("themes/granatier.svgz")));
     m_renderer = new KGameRenderer(theme);
 }
 
@@ -124,7 +124,7 @@ void ArenaSelector::Private::setupData(KConfigSkeleton * aconfig)
     //setup KNS button
     if (m_options & EnableNewStuffDownload)
     {
-        ui.getNewButton->setIcon(KIcon( QLatin1String( "get-hot-new-stuff" )));
+        ui.getNewButton->setIcon(QIcon::fromTheme( QLatin1String( "get-hot-new-stuff" )));
         connect(ui.getNewButton, SIGNAL(clicked()), q, SLOT(_k_openKNewStuffDialog()));
     }
     else
@@ -152,7 +152,6 @@ void ArenaSelector::Private::setupData(KConfigSkeleton * aconfig)
     m_tempRandomArenaModeArenaList.removeDuplicates();
     
     //Now get our arenas into the list widget
-    KGlobal::dirs()->addResourceType("arenaselector", "data", KGlobal::mainComponent().componentName() + '/' + lookupDirectory + '/');
     findArenas(lastUsedArena);
 
     connect(ui.importArenas, SIGNAL(clicked()), q, SLOT(_k_importArenasDialog()));
@@ -170,7 +169,13 @@ void ArenaSelector::Private::findArenas(const QString &initialSelection)
     ui.arenaList->setSortingEnabled(true);
 
     QStringList arenasAvailable;
-    KGlobal::dirs()->findAllResources("arenaselector", "*.desktop", KStandardDirs::Recursive, arenasAvailable);
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, "arenas", QStandardPaths::LocateDirectory);
+    Q_FOREACH (const QString& dir, dirs) {
+         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
+         Q_FOREACH (const QString& file, fileNames) {
+                arenasAvailable.append(file);
+         }
+    }
     
     QStringList::Iterator i = m_tempRandomArenaModeArenaList.begin();
     while(i != m_tempRandomArenaModeArenaList.end())
@@ -191,6 +196,7 @@ void ArenaSelector::Private::findArenas(const QString &initialSelection)
     }
     
     bool initialFound = false;
+
     foreach (const QString &file, arenasAvailable)
     {
       QString arenaPath = lookupDirectory + '/' + file;
@@ -471,6 +477,12 @@ void ArenaSelector::Private::_k_openKNewStuffDialog()
 
 void ArenaSelector::Private::_k_importArenasDialog()
 {
+    // get local directory for arenas
+    const QString arenaDir = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/arenas/");
+    // create path if it does not exist
+    if(!QDir(arenaDir).exists()) QDir().mkpath(arenaDir);
+
+
     //find the clanbomber files
     QStringList listClanbomberPaths;
     listClanbomberPaths.append(QDir::homePath() + "/.clanbomber/maps/");
@@ -493,10 +505,10 @@ void ArenaSelector::Private::_k_importArenasDialog()
             QString strAuthor = readStream.readLine();
             int nNumberOfPlayers = readStream.readLine().toInt();
             
-            KSaveFile desktopFile;
+            QFile desktopFile;
             QString strName = listMaps[j].left(listMaps[j].count()-4);
-            desktopFile.setFileName(QString("%1clanbomber_%2.desktop").arg(KStandardDirs::locateLocal("appdata", "arenas/")).arg(strName));
-            desktopFile.open();
+            desktopFile.setFileName(QString("%1clanbomber_%2.desktop").arg(arenaDir).arg(strName));
+            desktopFile.open(QIODevice::WriteOnly | QIODevice::Text);
             QTextStream streamDesktopFile(&desktopFile);
             
             streamDesktopFile << "[Arena]\n";
@@ -508,7 +520,6 @@ void ArenaSelector::Private::_k_importArenasDialog()
             streamDesktopFile << "AuthorEmail=-\n";
             
             streamDesktopFile.flush();
-            desktopFile.finalize();
             desktopFile.close();
             
             QStringList arena;
@@ -537,9 +548,9 @@ void ArenaSelector::Private::_k_importArenasDialog()
             arena.replaceInStrings("8", "p");
             arena.replaceInStrings("9", "p");
             
-            KSaveFile arenaFile;
-            arenaFile.setFileName(QString("%1clanbomber_%2.xml").arg(KStandardDirs::locateLocal("appdata", "arenas/")).arg(strName));
-            arenaFile.open();
+            QFile arenaFile;
+            arenaFile.setFileName(QString("%1clanbomber_%2.xml").arg(arenaDir).arg(strName));
+            arenaFile.open(QIODevice::WriteOnly | QIODevice::Text);
             
             QTextStream streamArenaFile(&arenaFile);
             
@@ -550,6 +561,9 @@ void ArenaSelector::Private::_k_importArenasDialog()
                 streamArenaFile << "  <Row>" << arena[j] << "</Row>\n";
             }
             streamArenaFile << "</Arena>\n";
+
+            streamArenaFile.flush();
+            arenaFile.close();
         }
     }
     
@@ -618,4 +632,5 @@ void ArenaSelector::Private::_k_updateRandomArenaModeArenaList(QListWidgetItem*
     *m_randomArenaModeArenaList = m_tempRandomArenaModeArenaList;
     Settings::self()->setDummy(Settings::self()->dummy() + 3);
 }
-#include "arenaselector.moc"
+#include "moc_arenaselector.cpp"
+
