@@ -24,8 +24,7 @@
 #include <QGraphicsView>
 #include <QGraphicsRectItem>
 #include <QTimer>
-#include <KLocale>
-#include <KStandardDirs>
+#include <KLocalizedString>
 #include <KGameRenderer>
 #include <KGameRenderedItem>
 
